FVVV class

Constructors

FVVV({dynamic value, Map<String, FVVV>? nodes, String desc = '', String link = ''})

Properties

boolean bool
no setter
bools List<bool>
no setter
desc String
getter/setter pair
doubles List<double>
no setter
float double
no setter
fvvvs List<FVVV>
no setter
hashCode int
The hash code for this object.
no setteroverride
integer int
no setter
ints List<int>
no setter
isEmpty bool
no setter
isNotEmpty bool
no setter
getter/setter pair
nodes Map<String, FVVV>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string String
no setter
strings List<String>
no setter
type Type
no setter
value ↔ dynamic
getter/setter pair

Methods

as<T>([T? defaultValue]) → T?
asType<T>([T? defaultValue]) → T?
from(FVVStruct target) → void
get<T>() → T
isList<T>() bool
isType<T>() bool
list<T>(List<T>? defaultValue) List<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseString(String text, {FVVStruct? target}) → void
to(FVVStruct target) → void
toString([int? flag1, int? flag2, int? flag3, int? flag4, int? flag5, int? flag6, int? flag7, int? flag8, int? flag9, int? flag10, int? flag11, int? flag12, int? flag13, int? flag14, int? flag15, int? flag16, int? flag17, int? flag18, int? flag19, int? flag20, int? flag21]) String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override
operator [](String key) FVVV
operator []=(String key, dynamic tgt) → void